@@ -6,8 +6,8 @@
 /**
  * @file api/v1/mailables/index.php
  *
- * Copyright (c) 2014-2022 Simon Fraser University
- * Copyright (c) 2003-2022 John Willinsky
+ * Copyright (c) 2023 Simon Fraser University
+ * Copyright (c) 2023 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_mailables
@@ -15,4 +15,4 @@
  * @brief Handle API requests for mailables.
  */
 
-return new \PKP\API\v1\mailables\MailableHandler();
+return new \PKP\handler\APIHandler(new \PKP\API\v1\mailables\PKPMailableController());
