@@ -51,7 +51,7 @@ class Mailer extends IlluminateMailer
      *
      * @copydoc \Illuminate\Mail\Mailer::__construct()
      */
-    public function __construct(string $name, TransportInterface $transport, Dispatcher $events = null)
+    public function __construct(string $name, TransportInterface $transport, ?Dispatcher $events = null)
     {
         $this->name = $name;
         $this->transport = $transport;
@@ -76,7 +76,7 @@ class Mailer extends IlluminateMailer
         }
 
         if (!is_string($view)) {
-            throw new InvalidArgumentException('View must be instance of ' . Htmlable::class . ' or a string, ' . get_class($view) . ' is given');
+            throw new InvalidArgumentException('View must be instance of ' . Htmlable::class . ' or a string, ' . ($view === null ? 'null' : get_class($view)) . ' is given');
         }
 
         return $this->compileParams($view, $data);
@@ -118,9 +118,9 @@ class Mailer extends IlluminateMailer
             $view->setData();
         }
 
-        // Application is set to sandbox mode and will sent any emails to log
+        // Application is set to sandbox mode and will send any emails to log
         if (Config::getVar('general', 'sandbox', false)) {
-            error_log('Application is set to sandbox mode and will sent any emails to log');
+            error_log('Application is set to sandbox mode and will send any emails to the log');
         }
 
         parent::send($view, $data, $callback);
