@@ -26,8 +26,10 @@ class TestJobSuccess extends BaseJob
 
     /**
      * The number of times the job may be attempted.
+     *
+     * @var int
      */
-    public int $tries = 1;
+    public $tries = 1;
 
     /**
      * Initialize the job
@@ -43,5 +45,6 @@ class TestJobSuccess extends BaseJob
      */
     public function handle(): void
     {
+        error_log('Test success job');
     }
 }
