@@ -17,7 +17,6 @@
 namespace PKP\plugins\importexport\native\filter;
 
 use APP\core\Application;
-use APP\core\Services;
 use APP\facades\Repo;
 use PKP\core\Core;
 use PKP\core\PKPApplication;
@@ -120,7 +119,7 @@ class NativeXmlSubmissionFileFilter extends NativeImportFilter
 
         $submissionFile = Repo::submissionFile()->dao->newDataObject();
         $submissionFile->setData('submissionId', $submission->getId());
-        $submissionFile->setData('locale', $submission->getLocale());
+        $submissionFile->setData('locale', $submission->getData('locale'));
         $submissionFile->setData('fileStage', $stageId);
         $submissionFile->setData('createdAt', Core::getCurrentDate());
         $submissionFile->setData('updatedAt', Core::getCurrentDate());
@@ -257,10 +256,6 @@ class NativeXmlSubmissionFileFilter extends NativeImportFilter
             if ($childNode instanceof \DOMElement) {
                 switch ($childNode->tagName) {
                     case 'href':
-                        if (php_sapi_name() !== 'cli') {
-                            $deployment->addError(PKPApplication::ASSOC_TYPE_SUBMISSION, $submission->getId(), 'Web-based imports may not specify "href"; use "embed" instead, or import using the command line.');
-                            break;
-                        }
                         $temporaryFileManager = new TemporaryFileManager();
                         $temporaryFilename = tempnam($temporaryFileManager->getBasePath(), 'src');
                         $filesrc = $childNode->getAttribute('src');
@@ -331,7 +326,7 @@ class NativeXmlSubmissionFileFilter extends NativeImportFilter
             clearstatcache(true, $temporaryFilename);
             $fileManager = new FileManager();
             $submissionDir = Repo::submissionFile()->getSubmissionDir($submission->getData('contextId'), $submission->getId());
-            $newFileId = Services::get('file')->add(
+            $newFileId = app()->get('file')->add(
                 $temporaryFilename,
                 $submissionDir . '/' . uniqid() . '.' . $node->getAttribute('extension')
             );
