@@ -30,6 +30,7 @@ use PKP\config\Config;
 use PKP\db\DAORegistry;
 use PKP\file\ContextFileManager;
 use PKP\pages\catalog\PKPCatalogHandler;
+use PKP\userGroup\UserGroup;
 
 class CatalogHandler extends PKPCatalogHandler
 {
@@ -68,7 +69,7 @@ class CatalogHandler extends PKPCatalogHandler
         }
 
         if (!$isFirstPage && (empty($page) || $page < 2)) {
-            $request->getDispatcher()->handle404();
+            throw new \Symfony\Component\HttpKernel\Exception\NotFoundHttpException();
         }
 
         $templateMgr = TemplateManager::getManager($request);
@@ -85,7 +86,7 @@ class CatalogHandler extends PKPCatalogHandler
             ->getCollector()
             ->filterByContextIds([$context->getId()])
             ->filterByStatus([Submission::STATUS_PUBLISHED])
-            ->orderBy($orderBy, $orderDir)
+            ->orderBy($orderBy, $orderDir == \PKP\db\DAO::SORT_DIRECTION_ASC ? 'ASC' : 'DESC')
             ->orderByFeatured();
 
         $total = $collector->getCount();
@@ -104,7 +105,9 @@ class CatalogHandler extends PKPCatalogHandler
 
         $templateMgr->assign([
             'publishedSubmissions' => $submissions->toArray(),
-            'authorUserGroups' => $authorUserGroups = Repo::userGroup()->getCollector()->filterByRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])->filterByContextIds([$context->getId()])->getMany()->remember(),
+            'authorUserGroups' => UserGroup::withRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])
+                ->withContextIds([$context->getId()])
+                ->get(),
             'featuredMonographIds' => $featuredMonographIds,
             'contextSeries' => $seriesIterator->toArray(),
         ]);
@@ -131,7 +134,9 @@ class CatalogHandler extends PKPCatalogHandler
         $newReleases = $newReleaseDao->getMonographsByAssoc(Application::ASSOC_TYPE_PRESS, $press->getId());
         $templateMgr->assign([
             'publishedSubmissions' => $newReleases,
-            'authorUserGroups' => $authorUserGroups = Repo::userGroup()->getCollector()->filterByRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])->filterByContextIds([$press->getId()])->getMany()->remember(),
+            'authorUserGroups' => UserGroup::withRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])
+                ->withContextIds([$press->getId()])
+                ->get(),
         ]);
 
         // Display
@@ -176,7 +181,7 @@ class CatalogHandler extends PKPCatalogHandler
             ->filterByContextIds([$context->getId()])
             ->filterBySeriesIds([$series->getId()])
             ->filterByStatus([Submission::STATUS_PUBLISHED])
-            ->orderBy($orderBy, $orderDir)
+            ->orderBy($orderBy, $orderDir == \PKP\db\DAO::SORT_DIRECTION_ASC ? 'ASC' : 'DESC')
             ->orderByFeatured();
 
         $total = $collector->getCount();
@@ -199,7 +204,9 @@ class CatalogHandler extends PKPCatalogHandler
             'publishedSubmissions' => $submissions->toArray(),
             'featuredMonographIds' => $featuredMonographIds,
             'newReleasesMonographs' => $newReleases,
-            'authorUserGroups' => $authorUserGroups = Repo::userGroup()->getCollector()->filterByRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])->filterByContextIds([$context->getId()])->getMany()->remember(),
+            'authorUserGroups' => UserGroup::withRoleIds([\PKP\security\Role::ROLE_ID_AUTHOR])
+                ->withContextIds([$context->getId()])
+                ->get(),
         ]);
 
         $templateMgr->display('frontend/pages/catalogSeries.tpl');
@@ -245,7 +252,7 @@ class CatalogHandler extends PKPCatalogHandler
                 }
                 break;
             default:
-                fatalError('invalid type specified');
+                throw new \Exception('invalid type specified');
                 break;
         }
 
@@ -282,7 +289,7 @@ class CatalogHandler extends PKPCatalogHandler
                 }
                 break;
             default:
-                fatalError('invalid type specified');
+                throw new \Exception('invalid type specified');
                 break;
         }
 
