@@ -90,7 +90,7 @@ class SubmissionHandler extends PKPSubmissionHandler
                     ? 'submission.wizard.submitting.monographInLanguage'
                     : 'submission.wizard.submitting.editedVolumeInLanguage'
                 ),
-                ['language' => Locale::getMetadata($submission->getData('locale'))->getDisplayName()]
+                ['language' => Locale::getSubmissionLocaleDisplayNames([$submission->getData('locale')])[$submission->getData('locale')]]
             );
         }
 
