@@ -3,8 +3,8 @@
 /**
  * @file plugins/reports/monographReport/Report.php
  *
- * Copyright (c) 2014-2022 Simon Fraser University
- * Copyright (c) 2003-2022 John Willinsky
+ * Copyright (c) 2014-2025 Simon Fraser University
+ * Copyright (c) 2003-2025 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Report
@@ -32,15 +32,10 @@ use Illuminate\Support\Facades\DB;
 use Illuminate\Support\LazyCollection;
 use IteratorAggregate;
 use PKP\category\Category;
-use PKP\db\DAORegistry;
+use PKP\controlledVocab\ControlledVocab;
 use PKP\facades\Locale;
 use PKP\security\Role;
 use PKP\stageAssignment\StageAssignment;
-use PKP\stageAssignment\StageAssignmentDAO;
-use PKP\submission\SubmissionAgencyDAO;
-use PKP\submission\SubmissionDisciplineDAO;
-use PKP\submission\SubmissionKeywordDAO;
-use PKP\submission\SubmissionSubjectDAO;
 use PKP\user\User;
 use PKP\userGroup\UserGroup;
 use Traversable;
@@ -173,7 +168,7 @@ class Report implements IteratorAggregate
             __('common.keywords') => fn () => $this->getKeywords(),
             __('submission.supportingAgencies') => fn () => $this->getAgencies(),
             __('common.status') => fn () => $this->getStatus(),
-            __('common.url') => fn () => $this->request->url(null, 'workflow', 'access', $this->submission->getId()),
+            __('common.url') => fn () => $this->request->url(null, 'workflow', 'access', [$this->submission->getId()]),
             __('catalog.manage.series.onlineIssn') => fn () => $this->getSeries()?->getOnlineISSN(),
             __('catalog.manage.series.printIssn') => fn () => $this->getSeries()?->getPrintISSN(),
             __('metadata.property.displayName.doi') => fn () => $this->publication->getDoi(),
@@ -191,7 +186,7 @@ class Report implements IteratorAggregate
                     $authorHeader(__('user.familyName'), $i) => fn () => $this->getAuthor($i)?->getLocalizedFamilyName(),
                     $authorHeader(__('user.orcid'), $i) => fn () => $this->getAuthor($i)?->getData('orcid'),
                     $authorHeader(__('common.country'), $i) => fn () => $this->getAuthor($i)?->getData('country'),
-                    $authorHeader(__('user.affiliation'), $i) => fn () => $this->getAuthor($i)?->getLocalizedData('affiliation'),
+                    $authorHeader(__('user.affiliation'), $i) => fn () => $this->getAuthor($i)?->getLocalizedAffiliationNamesAsString(),
                     $authorHeader(__('user.email'), $i) => fn () => $this->getAuthor($i)?->getData('email'),
                     $authorHeader(__('user.url'), $i) => fn () => $this->getAuthor($i)?->getData('url'),
                     $authorHeader(__('user.biography'), $i) => fn () => $this->toPlainText($this->getAuthor($i)?->getLocalizedData('biography'))
@@ -295,9 +290,11 @@ class Report implements IteratorAggregate
      */
     private function getEditorUserGroups(): Collection
     {
-        return $this->editorUserGroups ??= collect(Repo::userGroup()->getCollector()->filterByContextIds([$this->press->getId()])->getMany())
-            ->filter(fn (UserGroup $userGroup) => in_array($userGroup->getRoleId(), [Role::ROLE_ID_MANAGER, Role::ROLE_ID_SUB_EDITOR]))
-            ->mapWithKeys(fn (UserGroup $userGroup) => [$userGroup->getId() => true]);
+        $userGroups = UserGroup::withContextIds([$this->press->getId()])->get();
+
+        return $this->editorUserGroups ??= $userGroups
+            ->filter(fn (UserGroup $userGroup) => in_array($userGroup->roleId, [Role::ROLE_ID_MANAGER, Role::ROLE_ID_SUB_EDITOR]))
+            ->mapWithKeys(fn (UserGroup $userGroup) => [$userGroup->id => true]);
     }
 
     /**
@@ -367,9 +364,13 @@ class Report implements IteratorAggregate
      */
     private function getKeywords(): string
     {
-        /** @var SubmissionKeywordDAO */
-        $submissionKeywordDao = DAORegistry::getDAO('SubmissionKeywordDAO');
-        return $this->flattenKeywords($submissionKeywordDao->getKeywords($this->publication->getId()));
+        return $this->flattenKeywords(
+            Repo::controlledVocab()->getBySymbolic(
+                ControlledVocab::CONTROLLED_VOCAB_SUBMISSION_KEYWORD,
+                Application::ASSOC_TYPE_PUBLICATION,
+                $this->publication->getId()
+            )
+        );
     }
 
     /**
@@ -377,9 +378,13 @@ class Report implements IteratorAggregate
      */
     private function getSubjects(): string
     {
-        /** @var SubmissionSubjectDAO */
-        $submissionSubjectDao = DAORegistry::getDAO('SubmissionSubjectDAO');
-        return $this->flattenKeywords($submissionSubjectDao->getSubjects($this->publication->getId()));
+        return $this->flattenKeywords(
+            Repo::controlledVocab()->getBySymbolic(
+                ControlledVocab::CONTROLLED_VOCAB_SUBMISSION_SUBJECT,
+                Application::ASSOC_TYPE_PUBLICATION,
+                $this->publication->getId()
+            )
+        );
     }
 
     /**
@@ -387,9 +392,13 @@ class Report implements IteratorAggregate
      */
     private function getDisciplines(): string
     {
-        /** @var SubmissionDisciplineDAO */
-        $submissionDisciplineDao = DAORegistry::getDAO('SubmissionDisciplineDAO');
-        return $this->flattenKeywords($submissionDisciplineDao->getDisciplines($this->publication->getId()));
+        return $this->flattenKeywords(
+            Repo::controlledVocab()->getBySymbolic(
+                ControlledVocab::CONTROLLED_VOCAB_SUBMISSION_DISCIPLINE,
+                Application::ASSOC_TYPE_PUBLICATION,
+                $this->publication->getId()
+            )
+        );
     }
 
     /**
@@ -397,9 +406,13 @@ class Report implements IteratorAggregate
      */
     private function getAgencies(): string
     {
-        /** @var SubmissionAgencyDAO */
-        $submissionAgencyDao = DAORegistry::getDAO('SubmissionAgencyDAO');
-        return $this->flattenKeywords($submissionAgencyDao->getAgencies($this->publication->getId()));
+        return $this->flattenKeywords(
+            Repo::controlledVocab()->getBySymbolic(
+                ControlledVocab::CONTROLLED_VOCAB_SUBMISSION_AGENCY,
+                Application::ASSOC_TYPE_PUBLICATION,
+                $this->publication->getId()
+            )
+        );
     }
 
     /**
@@ -419,12 +432,12 @@ class Report implements IteratorAggregate
      */
     private function getEditors(): array
     {
-        /** @var StageAssignmentDAO */
-        $stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO');
+        $stageAssignments = StageAssignment::withSubmissionIds([$this->submission->getId()])
+            ->get();
 
-        return collect($stageAssignmentDao->getBySubmissionAndStageId($this->submission->getId())->toIterator())
-            ->filter(fn (StageAssignment $stageAssignment) => $this->getEditorUserGroups()->get($stageAssignment->getUserGroupId()))
-            ->map(fn (StageAssignment $stageAssignment) => $this->getUser($stageAssignment->getUserId()))
+        return $stageAssignments
+            ->filter(fn (StageAssignment $stageAssignment) => $this->getEditorUserGroups()->get($stageAssignment->userGroupId))
+            ->map(fn (StageAssignment $stageAssignment) => $this->getUser($stageAssignment->userId))
             ->unique(fn (User $user) => $user->getId())
             ->values()
             ->toArray();
